src/hotspot/cpu/aarch64/c1_Runtime1_aarch64.cpp
changeset 50094 2f79462aab9b
parent 49906 4bb58f644e4e
child 50519 17bde7f98889
--- a/src/hotspot/cpu/aarch64/c1_Runtime1_aarch64.cpp	Sat May 12 17:22:56 2018 +0530
+++ b/src/hotspot/cpu/aarch64/c1_Runtime1_aarch64.cpp	Mon May 07 09:11:21 2018 +0200
@@ -323,7 +323,7 @@
 
 
 // target: the entry point of the method that creates and posts the exception oop
 // has_argument: true if the exception needs an argument (passed in rscratch1)
 
 OopMapSet* Runtime1::generate_exception_throw(StubAssembler* sasm, address target, bool has_argument) {
   // make a frame and preserve the caller's caller-save registers
@@ -332,7 +332,7 @@
   if (!has_argument) {
     call_offset = __ call_RT(noreg, noreg, target);
   } else {
-    call_offset = __ call_RT(noreg, noreg, target, rscratch1);
+    call_offset = __ call_RT(noreg, noreg, target, r22, r23);
   }
   OopMapSet* oop_maps = new OopMapSet();
   oop_maps->add_gc_map(call_offset, oop_map);
@@ -323,7 +323,7 @@
 
 // target: the entry point of the method that creates and posts the exception oop
-// has_argument: true if the exception needs an argument (passed in rscratch1)
+// has_argument: true if the exception needs arguments (passed in r22 and r23)
 
 OopMapSet* Runtime1::generate_exception_throw(StubAssembler* sasm, address target, bool has_argument) {